# -*- coding: utf-8 -*-

"""SIGNAL PROCESSING ROUTINES.

This module contains submodules for signal processing.

:Author: Samuel Farrens <samuel.farrens@cea.fr>

"""

__all__ = ['filter', 'noise', 'positivity', 'svd', 'validation', 'wavelet']
